@@ -9,7 +9,7 @@ use JSON::Tiny;
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 # config
 my $tab = "\t";
@@ -36,7 +36,7 @@ Process::Results - standardized structure for returning results of a process
  if ($results->success) {}
  else {}
  
- much more...
+ more...
 
 =head1 OVERVIEW
 
@@ -764,6 +764,9 @@ sub is_number {
 # is_number
 #------------------------------------------------------------------------------
 
+
+
+
 # return
 1;
 
@@ -796,6 +799,10 @@ Version: 0.01
 
 Initial release.
 
+=item * Version 0.02 Aug 15, 2016
+
+Adding Process::Results::Holder to Process::Results.
+
 =back
 
 =cut
